# starkutils
StarStandard way to get the REST api response.

## Install
  ```
  pip install starkutils
  ```

## Usage
1. Import starkutils
  ```
  from starkutils.starkutils import *
  ```
  
2. To get the response
  ```
  - generate_otp_number
  - MultipleFieldPKModelMixin
  - CreateRetrieveUpdateViewSet
  - is_valid_email
  - get_serielizer_error
  - get_pagination_resp
  - string_to_date
  - convert_timestamp_to_date
  - encrypt
  - decrypt
  - generate_token
  - revoke_oauth_token
  - get_otp_expirity
  - transform_list
  - utc_to_time
  - check_email
  - get_notification_time
  - find_day
  - min_to_hr_conversion
  - get_slug
  - int_to_time
  - random_string_generator
  ```